/*
 * modules.h
 *
 * Author: Landon Fuller <landonf@go2net.com>
 *
 * Copyright (c) 2000 InfoSpace, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *         This product includes software developed by InfoSpace, Inc.
 *         and its contributors.
 * 4. Neither the name of InfoSpace, Inc nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

typedef struct ypmodulelist ypmodulelistptr;

struct ypmoduledata {
	/* Exported functions */
	int (*log) (const char *, ...);
	void *(*safe_malloc) (size_t);
	void *(*safe_realloc) (void *ptr, size_t);
	char *(*safe_strdup) (const char *);
	struct ypmaplist *(*yp_maplist_create) (char *);
	/* Module functions */
	bool_t (*init) (ypmodulelistptr *);
	int (*yp_clear) (void);
	int (*yp_getbykey) (keydat *, mapname *, valdat *);
	int (*yp_firstbykey) (keydat *, mapname *, valdat *);
	int (*yp_nextbykey) (keydat *, mapname *, valdat *);
};

struct ypmodulelist {
	char *path;
	void *ptr;
	struct ypmaplist *maps;
	struct ypmoduledata *yp_moduledata;
	struct ypmodulelist *next;
};

struct ypmodulelist *yp_modulelist_create (char *);
struct ypmoduledata *yp_get_module (char *);
int modules_init(struct ypmodulelist *);
