/*
 *
 * access.c
 *
 * Access control routines
 *
 * Author: Landon Fuller <landonf@go2net.com>
 *
 * Copyright (c) 2000-2001 InfoSpace, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *         This product includes software developed by InfoSpace, Inc.
 *         and its contributors.
 * 4. Neither the name of InfoSpace, Inc nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include "../autoconf.h"
#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <string.h>

#include "yp.h"
#include "../include/config.h"
#include "../include/servconf.h"
#include "../include/transit.h"
#include "../include/log.h"

int yp_validdomain(const char *domain)
{
	if(strstr(prefs.domain, domain))
		return (0);
	return (1);
}
/* yp_access will fail with anything but ipv4 addresses. For future work,
 * change the XTI routines to work correctly. See Steven's xti_ntop for an example. */
int yp_access(const char *map, const struct svc_req *rqstp)
{
#ifdef SOLARIS
	struct netbuf *np;
#endif
	struct sockaddr_in *rqhost;

#ifdef SOLARIS
	np = svc_getrpccaller(rqstp->rq_xprt);
	rqhost = (struct sockaddr_in *) np->buf;
#else
	rqhost = svc_getcaller(rqstp->rq_xprt);
#endif
	if (map != NULL)
	{
		if((strstr(map, "shadow.") || (rqstp->rq_prog == YPPROG && \
				rqstp->rq_proc == YPPROC_XFR)) && \
				ntohs(rqhost->sin_port) >= IPPORT_RESERVED)
		{
			warn("Blocked request from host %s:%d for map %s\n",
					inet_ntoa(rqhost->sin_addr),
					ntohs(rqhost->sin_port), map);
			return (1);
		}
	}
	return (0);
}
