%{
/*
 * confparse.l
 *
 * Generates a parser to read the server configuration
 *
 * Authors: Bruce Ide <nride@uswest.net>, Landon Fuller <landonf@go2net.com>
 *
 * Copyright (c) 2000-2001 InfoSpace, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *         This product includes software developed by InfoSpace, Inc.
 *         and its contributors.
 * 4. Neither the name of InfoSpace, Inc nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include "../autoconf.h"

#include <stdio.h>
#include <string.h>
#include "../include/servconf.h"
#include "../include/util.h"
#include "conf.tab.h"

#define YY_NO_UNPUT
#define YY_USER_INIT yylinecount = 1;

#define yyerror conferror
extern int yyerror (char *);

%}
%option noyywrap
%x STRING
%x LIST_STATE
%%
#.*                                      { /* Ignore comments to end of line */ 
                                           yylinecount++; }
[\t\n ]*                                 { /* Ignore whitespace */ }
[Dd][Oo][Mm][Aa][Ii][Nn]                 { BEGIN STRING;
                                           return DOMAIN; }
[Nn][Ii][Ss][Mm][Aa][Ss][Tt][Ee][Rr]     { BEGIN STRING; 
                                           return NISMASTER; }
[Mm][Aa][Pp][Ss]                         { BEGIN LIST_STATE;
                                           return MAPS; }
[Mm][Oo][Dd][Uu][Ll][Ee][Ss]		 { BEGIN LIST_STATE;
					   return MODULES; }
.                                        { yyerror("unknown opcode"); }
<STRING>[ \t]*                           { /* Eat white space */ }
<STRING>[^ \t\n]+                        { BEGIN 0; /* Default state */
                                           conflval.str = safe_strdup(yytext);
                                           return STRING_TOKEN;
                                         }
<STRING>\n                               { BEGIN 0; }
<LIST_STATE>[ \t]*                        { /* Eat white space */ }
<LIST_STATE>[^\n]+                       { BEGIN 0;
                                           conflval.str = safe_strdup(yytext);
                                           return STRING_TOKEN;
                                         }
<LIST_STATE>[ \t\n]+                     { BEGIN 0;}
%%
