%{
/*
 * confparse.y
 *
 * Bison source complimenting confparse.l for parsing the server config
 *
 * Authors: Bruce Ide <nride@uswest.net>, Landon Fuller <landonf@go2net.com>
 *
 * Copyright (c) 2001 InfoSpace, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *         This product includes software developed by InfoSpace, Inc.
 *         and its contributors.
 * 4. Neither the name of InfoSpace, Inc nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE. 
 *
 */
#include "../autoconf.h"

#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include "yp.h"
#include "../include/servconf.h"
#include "../include/util.h"
#include "../include/modules.h"
#include "../include/yp.h"
#include "../include/log.h"

extern	int	conflex (void);
extern	char	*conftext;
char *endptr;
//#define YYERROR_VERBOSE 1

int yyerror (char *errstring)
{
	fatal("Error \"%s\" in config file on line %d.\n", errstring, yylinecount);
	return(1);
}

%}

%union {
  int num;
  char *str;
};

%token <str> STRING_TOKEN
%token DOMAIN NISMASTER MAPS MODULES
%%
config_file: config_file config_lines | config_lines
;

config_lines: domain_line |
              master_line |
              maps_line |
	      modules_line
;
domain_line: DOMAIN STRING_TOKEN { prefs.domain = $2; yylinecount++;}
;
master_line: NISMASTER STRING_TOKEN { prefs.master = $2; yylinecount++;}
;
maps_line: MAPS STRING_TOKEN { prefs.yp_maplist = yp_maplist_create($2); yylinecount++;
                               free($2); }
;
modules_line: MODULES STRING_TOKEN { prefs.yp_modulelist = yp_modulelist_create($2); yylinecount++;
					free($2); }
