/*
 *
 * util.c
 *
 * Author: Landon Fuller <landonf@go2net.com>
 *
 * wrappers for potentially unsafe functions
 *
 * Copyright (c) 2000-2001 InfoSpace, Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *         This product includes software developed by InfoSpace, Inc.
 *         and its contributors.
 * 4. Neither the name of InfoSpace, Inc nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
#include "../autoconf.h"

#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>
#ifdef HAVE_LIMITS_H
#include <limits.h>
#else if defined(HAVE_MACHINE_LIMITS_H)
#include <machine/limits.h>
#endif

#include "../include/log.h"

void * safe_malloc (size_t size)
{
	void *result;
	result = malloc(size);
	if (result == NULL)
		fatal("malloc failed: %s\n", strerror(errno));

	return result;
}

void * safe_realloc (void *ptr, size_t size)
{
	void *result;
	result = realloc(ptr, size);
	if (result == NULL)
		fatal("realloc failed: %s\n", strerror(errno));

	return result;
}

char * safe_strdup (const char *str)
{
	char *result;
	result = strdup(str);
	if (result == NULL)
		fatal("strdup failed: %s\n", strerror(errno));

	return result;
}
int strtoi (const char *str)
{
	char *endptr;
	long int long_int;
	long_int = strtol(str, &endptr, 0);
	if (errno == ERANGE)
	{
		//error("ERANGE error converting ascii string to long int\n");
		if (long_int == LONG_MAX)
			return (INT_MAX);
		if (long_int == LONG_MIN)
			return (INT_MIN);

	} else if (long_int > INT_MAX) {
			return (INT_MAX);

	} else if (long_int < INT_MIN) {
			return (INT_MIN);

	} else if (*endptr != '\0') {
		//error("Invalid numerical argument to strtoi\n");
		errno = EINVAL;
		return ((int) long_int);
	}
	errno = 0;
	return ((int) long_int);
}
